Object-oriented interface to `Service Abstraction Layer <https://docushare.lsstcorp.org/docushare/dsweb/Get/Document-21527/>`_ (SAL) components.

`Documentation <https://ts-salobj.lsst.io>`_

This code uses ``pre-commit`` to maintain ``black`` formatting and ``flake8`` compliance.
To enable this:

* Run ``pre-commit install`` once.
* If directed, run ``git config --unset-all core.hooksPath`` once.
